.. include:: ../../README.rst
   :start-after: readme-start

.. toctree::
   :caption: User Guide
   :glob:
   :maxdepth: 1

   user_guide/*

API References
--------------

.. autosummary::
   :caption: API References
   :toctree: api-references
   :template: our-module.rst

   nourish
   nourish.dataset
   nourish.exceptions
   nourish.schema

Loaders
~~~~~~~

.. autosummary::
   :caption: API References (Loaders)
   :toctree: api-references
   :template: our-module.rst

   nourish.loaders
   nourish.loaders.table
   nourish.loaders.text


.. toctree::
   :caption: Miscellaneous
   :glob:
   :maxdepth: 1

   miscellaneous/*

Indices and Search
==================

* :ref:`genindex`
* :ref:`search`
